# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_logs_get200_response_inner import ApiLogsGet200ResponseInner

class TestApiLogsGet200ResponseInner(unittest.TestCase):
    """ApiLogsGet200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiLogsGet200ResponseInner:
        """Test ApiLogsGet200ResponseInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiLogsGet200ResponseInner`
        """
        model = ApiLogsGet200ResponseInner()
        if include_optional:
            return ApiLogsGet200ResponseInner(
                id = '0',
                key = '0',
                payload = py_logto.models._api_logs_get_200_response_inner_payload._api_logs_get_200_response_inner_payload(
                    key = '', 
                    result = 'Success', 
                    error = null, 
                    ip = '', 
                    user_agent = '', 
                    user_id = '', 
                    application_id = '', 
                    session_id = '', ),
                created_at = 1.337
            )
        else:
            return ApiLogsGet200ResponseInner(
                id = '0',
                key = '0',
                payload = py_logto.models._api_logs_get_200_response_inner_payload._api_logs_get_200_response_inner_payload(
                    key = '', 
                    result = 'Success', 
                    error = null, 
                    ip = '', 
                    user_agent = '', 
                    user_id = '', 
                    application_id = '', 
                    session_id = '', ),
                created_at = 1.337,
        )
        """

    def testApiLogsGet200ResponseInner(self):
        """Test ApiLogsGet200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
