# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_users_user_id_profile_patch_request_profile import ApiUsersUserIdProfilePatchRequestProfile

class TestApiUsersUserIdProfilePatchRequestProfile(unittest.TestCase):
    """ApiUsersUserIdProfilePatchRequestProfile unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiUsersUserIdProfilePatchRequestProfile:
        """Test ApiUsersUserIdProfilePatchRequestProfile
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiUsersUserIdProfilePatchRequestProfile`
        """
        model = ApiUsersUserIdProfilePatchRequestProfile()
        if include_optional:
            return ApiUsersUserIdProfilePatchRequestProfile(
                family_name = '',
                given_name = '',
                middle_name = '',
                nickname = '',
                preferred_username = '',
                profile = '',
                website = '',
                gender = '',
                birthdate = '',
                zoneinfo = '',
                locale = '',
                address = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_profile_address._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_profile_address(
                    formatted = '', 
                    street_address = '', 
                    locality = '', 
                    region = '', 
                    postal_code = '', 
                    country = '', )
            )
        else:
            return ApiUsersUserIdProfilePatchRequestProfile(
        )
        """

    def testApiUsersUserIdProfilePatchRequestProfile(self):
        """Test ApiUsersUserIdProfilePatchRequestProfile"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
