# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_sso_connectors_get200_response_inner import ApiSsoConnectorsGet200ResponseInner

class TestApiSsoConnectorsGet200ResponseInner(unittest.TestCase):
    """ApiSsoConnectorsGet200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiSsoConnectorsGet200ResponseInner:
        """Test ApiSsoConnectorsGet200ResponseInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSsoConnectorsGet200ResponseInner`
        """
        model = ApiSsoConnectorsGet200ResponseInner()
        if include_optional:
            return ApiSsoConnectorsGet200ResponseInner(
                id = '0',
                provider_name = 'OIDC',
                connector_name = '0',
                config = None,
                domains = [
                    ''
                    ],
                branding = py_logto.models._api_sso_connectors_get_200_response_inner_branding._api_sso_connectors_get_200_response_inner_branding(
                    display_name = '', 
                    logo = '', 
                    dark_logo = '', ),
                sync_profile = True,
                created_at = 1.337,
                name = '',
                provider_type = 'oidc',
                provider_logo = '',
                provider_logo_dark = '',
                provider_config = {
                    'key' : {}
                    }
            )
        else:
            return ApiSsoConnectorsGet200ResponseInner(
                id = '0',
                provider_name = 'OIDC',
                connector_name = '0',
                config = None,
                domains = [
                    ''
                    ],
                branding = py_logto.models._api_sso_connectors_get_200_response_inner_branding._api_sso_connectors_get_200_response_inner_branding(
                    display_name = '', 
                    logo = '', 
                    dark_logo = '', ),
                sync_profile = True,
                created_at = 1.337,
                name = '',
                provider_type = 'oidc',
                provider_logo = '',
                provider_logo_dark = '',
        )
        """

    def testApiSsoConnectorsGet200ResponseInner(self):
        """Test ApiSsoConnectorsGet200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
