# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.user_assets_api import UserAssetsApi


class TestUserAssetsApi(unittest.TestCase):
    """UserAssetsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UserAssetsApi()

    def tearDown(self) -> None:
        pass

    def test_api_user_assets_post(self) -> None:
        """Test case for api_user_assets_post

        Upload asset
        """
        pass

    def test_api_user_assets_service_status_get(self) -> None:
        """Test case for api_user_assets_service_status_get

        Get service status
        """
        pass


if __name__ == '__main__':
    unittest.main()
