# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_interaction_put_request import ApiInteractionPutRequest

class TestApiInteractionPutRequest(unittest.TestCase):
    """ApiInteractionPutRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiInteractionPutRequest:
        """Test ApiInteractionPutRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiInteractionPutRequest`
        """
        model = ApiInteractionPutRequest()
        if include_optional:
            return ApiInteractionPutRequest(
                event = 'SignIn',
                identifier = None,
                profile = py_logto.models._api_interaction_put_request_profile._api_interaction_put_request_profile(
                    username = 'MqXzyCBw3_uufVPIPFhB9JcGRYnua', 
                    email = 'k@?x!u'K}qz^sEC)lJ*=-jQ+'6`%cClu,k'!'su[..zF6V,V6rEtCO?&28nxs#k8z)\"\\6\\%TMxo:-sWVoim9gs', 
                    phone = '4', 
                    connector_id = '', 
                    password = '', )
            )
        else:
            return ApiInteractionPutRequest(
                event = 'SignIn',
        )
        """

    def testApiInteractionPutRequest(self):
        """Test ApiInteractionPutRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
