# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.applications_api import ApplicationsApi


class TestApplicationsApi(unittest.TestCase):
    """ApplicationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationsApi()

    def tearDown(self) -> None:
        pass

    def test_api_applications_application_id_roles_get(self) -> None:
        """Test case for api_applications_application_id_roles_get

        Get application API resource roles
        """
        pass

    def test_api_applications_application_id_roles_post(self) -> None:
        """Test case for api_applications_application_id_roles_post

        Assign API resource roles to application
        """
        pass

    def test_api_applications_application_id_roles_put(self) -> None:
        """Test case for api_applications_application_id_roles_put

        Update API resource roles for application
        """
        pass

    def test_api_applications_application_id_roles_role_id_delete(self) -> None:
        """Test case for api_applications_application_id_roles_role_id_delete

        Remove a API resource role from application
        """
        pass

    def test_api_applications_application_id_sign_in_experience_get(self) -> None:
        """Test case for api_applications_application_id_sign_in_experience_get

        Get the application level sign-in experience
        """
        pass

    def test_api_applications_application_id_sign_in_experience_put(self) -> None:
        """Test case for api_applications_application_id_sign_in_experience_put

        Update application level sign-in experience
        """
        pass

    def test_api_applications_application_id_user_consent_scopes_get(self) -> None:
        """Test case for api_applications_application_id_user_consent_scopes_get

        List all the user consent scopes of an application.
        """
        pass

    def test_api_applications_application_id_user_consent_scopes_post(self) -> None:
        """Test case for api_applications_application_id_user_consent_scopes_post

        Assign user consent scopes to application.
        """
        pass

    def test_api_applications_application_id_user_consent_scopes_scope_type_scope_id_delete(self) -> None:
        """Test case for api_applications_application_id_user_consent_scopes_scope_type_scope_id_delete

        Remove user consent scope from application.
        """
        pass

    def test_api_applications_get(self) -> None:
        """Test case for api_applications_get

        Get applications
        """
        pass

    def test_api_applications_id_delete(self) -> None:
        """Test case for api_applications_id_delete

        Delete application
        """
        pass

    def test_api_applications_id_get(self) -> None:
        """Test case for api_applications_id_get

        Get application
        """
        pass

    def test_api_applications_id_patch(self) -> None:
        """Test case for api_applications_id_patch

        Update application
        """
        pass

    def test_api_applications_id_protected_app_metadata_custom_domains_domain_delete(self) -> None:
        """Test case for api_applications_id_protected_app_metadata_custom_domains_domain_delete

        Delete a custom domain.
        """
        pass

    def test_api_applications_id_protected_app_metadata_custom_domains_get(self) -> None:
        """Test case for api_applications_id_protected_app_metadata_custom_domains_get

        Get the list of custom domains of the protected application.
        """
        pass

    def test_api_applications_id_protected_app_metadata_custom_domains_post(self) -> None:
        """Test case for api_applications_id_protected_app_metadata_custom_domains_post

        Add a custom domain to the protected application.
        """
        pass

    def test_api_applications_id_users_user_id_consent_organizations_get(self) -> None:
        """Test case for api_applications_id_users_user_id_consent_organizations_get

        List all the user consented organizations of a application.
        """
        pass

    def test_api_applications_id_users_user_id_consent_organizations_organization_id_delete(self) -> None:
        """Test case for api_applications_id_users_user_id_consent_organizations_organization_id_delete

        Revoke a user's access to an organization for a application.
        """
        pass

    def test_api_applications_id_users_user_id_consent_organizations_post(self) -> None:
        """Test case for api_applications_id_users_user_id_consent_organizations_post

        Grant a list of organization access of a user for a application.
        """
        pass

    def test_api_applications_id_users_user_id_consent_organizations_put(self) -> None:
        """Test case for api_applications_id_users_user_id_consent_organizations_put

        Grant a list of organization access of a user for a application.
        """
        pass

    def test_api_applications_post(self) -> None:
        """Test case for api_applications_post

        Create an application
        """
        pass


if __name__ == '__main__':
    unittest.main()
