# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.resources_api import ResourcesApi


class TestResourcesApi(unittest.TestCase):
    """ResourcesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ResourcesApi()

    def tearDown(self) -> None:
        pass

    def test_api_resources_get(self) -> None:
        """Test case for api_resources_get

        Get API resources
        """
        pass

    def test_api_resources_id_delete(self) -> None:
        """Test case for api_resources_id_delete

        Delete API resource
        """
        pass

    def test_api_resources_id_get(self) -> None:
        """Test case for api_resources_id_get

        Get API resource
        """
        pass

    def test_api_resources_id_is_default_patch(self) -> None:
        """Test case for api_resources_id_is_default_patch

        Set API resource as default
        """
        pass

    def test_api_resources_id_patch(self) -> None:
        """Test case for api_resources_id_patch

        Update API resource
        """
        pass

    def test_api_resources_post(self) -> None:
        """Test case for api_resources_post

        Create an API resource
        """
        pass

    def test_api_resources_resource_id_scopes_get(self) -> None:
        """Test case for api_resources_resource_id_scopes_get

        Get API resource scopes
        """
        pass

    def test_api_resources_resource_id_scopes_post(self) -> None:
        """Test case for api_resources_resource_id_scopes_post

        Create API resource scope
        """
        pass

    def test_api_resources_resource_id_scopes_scope_id_delete(self) -> None:
        """Test case for api_resources_resource_id_scopes_scope_id_delete

        Delete API resource scope
        """
        pass

    def test_api_resources_resource_id_scopes_scope_id_patch(self) -> None:
        """Test case for api_resources_resource_id_scopes_scope_id_patch

        Update API resource scope
        """
        pass


if __name__ == '__main__':
    unittest.main()
