# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_applications_post_request import ApiApplicationsPostRequest

class TestApiApplicationsPostRequest(unittest.TestCase):
    """ApiApplicationsPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiApplicationsPostRequest:
        """Test ApiApplicationsPostRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiApplicationsPostRequest`
        """
        model = ApiApplicationsPostRequest()
        if include_optional:
            return ApiApplicationsPostRequest(
                name = '0',
                description = '',
                type = 'Native',
                oidc_client_metadata = py_logto.models._api_applications_get_200_response_inner_oidc_client_metadata._api_applications_get_200_response_inner_oidcClientMetadata(
                    redirect_uris = [
                        null
                        ], 
                    post_logout_redirect_uris = [
                        ''
                        ], 
                    logo_uri = '', ),
                custom_client_metadata = py_logto.models._api_applications_get_200_response_inner_custom_client_metadata._api_applications_get_200_response_inner_customClientMetadata(
                    cors_allowed_origins = [
                        '0'
                        ], 
                    id_token_ttl = 1.337, 
                    refresh_token_ttl = 1.337, 
                    refresh_token_ttl_in_days = 1.337, 
                    always_issue_refresh_token = True, 
                    rotate_refresh_token = True, ),
                is_third_party = True,
                protected_app_metadata = py_logto.models._api_applications_post_request_protected_app_metadata._api_applications_post_request_protectedAppMetadata(
                    sub_domain = '', 
                    origin = '', )
            )
        else:
            return ApiApplicationsPostRequest(
                name = '0',
                type = 'Native',
        )
        """

    def testApiApplicationsPostRequest(self):
        """Test ApiApplicationsPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
