# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.authn_api import AuthnApi


class TestAuthnApi(unittest.TestCase):
    """AuthnApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthnApi()

    def tearDown(self) -> None:
        pass

    def test_api_authn_hasura_get(self) -> None:
        """Test case for api_authn_hasura_get

        Hasura auth hook endpoint
        """
        pass

    def test_api_authn_saml_connector_id_post(self) -> None:
        """Test case for api_authn_saml_connector_id_post

        SAML ACS endpoint (social)
        """
        pass

    def test_api_authn_single_sign_on_saml_connector_id_post(self) -> None:
        """Test case for api_authn_single_sign_on_saml_connector_id_post

        SAML ACS endpoint (SSO)
        """
        pass


if __name__ == '__main__':
    unittest.main()
