# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_applications_get200_response_inner_protected_app_metadata import ApiApplicationsGet200ResponseInnerProtectedAppMetadata

class TestApiApplicationsGet200ResponseInnerProtectedAppMetadata(unittest.TestCase):
    """ApiApplicationsGet200ResponseInnerProtectedAppMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiApplicationsGet200ResponseInnerProtectedAppMetadata:
        """Test ApiApplicationsGet200ResponseInnerProtectedAppMetadata
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiApplicationsGet200ResponseInnerProtectedAppMetadata`
        """
        model = ApiApplicationsGet200ResponseInnerProtectedAppMetadata()
        if include_optional:
            return ApiApplicationsGet200ResponseInnerProtectedAppMetadata(
                host = '',
                origin = '',
                session_duration = 1.337,
                page_rules = [
                    py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_page_rules_inner._api_applications_get_200_response_inner_protectedAppMetadata_pageRules_inner(
                        path = '', )
                    ],
                custom_domains = [
                    py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner(
                        domain = '', 
                        status = 'PendingVerification', 
                        error_message = '', 
                        dns_records = [
                            py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_dns_records_inner._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_dnsRecords_inner(
                                name = '', 
                                type = '', 
                                value = '', )
                            ], 
                        cloudflare_data = py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData(
                            id = '', 
                            status = '', 
                            ssl = py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data_ssl._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData_ssl(
                                status = '', 
                                validation_errors = [
                                    py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data_ssl_validation_errors_inner._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData_ssl_validation_errors_inner(
                                        message = '', )
                                    ], ), 
                            verification_errors = [
                                ''
                                ], ), )
                    ]
            )
        else:
            return ApiApplicationsGet200ResponseInnerProtectedAppMetadata(
                host = '',
                origin = '',
                session_duration = 1.337,
                page_rules = [
                    py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_page_rules_inner._api_applications_get_200_response_inner_protectedAppMetadata_pageRules_inner(
                        path = '', )
                    ],
        )
        """

    def testApiApplicationsGet200ResponseInnerProtectedAppMetadata(self):
        """Test ApiApplicationsGet200ResponseInnerProtectedAppMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
