# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_applications_id_users_user_id_consent_organizations_get200_response import ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response

class TestApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response(unittest.TestCase):
    """ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response:
        """Test ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response`
        """
        model = ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response()
        if include_optional:
            return ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response(
                organizations = [
                    py_logto.models._api_applications__id__users__user_id__consent_organizations_get_200_response_organizations_inner._api_applications__id__users__userId__consent_organizations_get_200_response_organizations_inner(
                        id = '0', 
                        name = '0', 
                        description = '', 
                        created_at = 1.337, )
                    ]
            )
        else:
            return ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response(
                organizations = [
                    py_logto.models._api_applications__id__users__user_id__consent_organizations_get_200_response_organizations_inner._api_applications__id__users__userId__consent_organizations_get_200_response_organizations_inner(
                        id = '0', 
                        name = '0', 
                        description = '', 
                        created_at = 1.337, )
                    ],
        )
        """

    def testApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response(self):
        """Test ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
