# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_interaction_consent_get200_response import ApiInteractionConsentGet200Response

class TestApiInteractionConsentGet200Response(unittest.TestCase):
    """ApiInteractionConsentGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiInteractionConsentGet200Response:
        """Test ApiInteractionConsentGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiInteractionConsentGet200Response`
        """
        model = ApiInteractionConsentGet200Response()
        if include_optional:
            return ApiInteractionConsentGet200Response(
                application = py_logto.models._api_interaction_consent_get_200_response_application._api_interaction_consent_get_200_response_application(
                    id = '0', 
                    name = '0', 
                    branding = py_logto.models._api_interaction_consent_get_200_response_application_branding._api_interaction_consent_get_200_response_application_branding(
                        logo_url = '', 
                        dark_logo_url = '', 
                        favicon = '', ), 
                    display_name = '', 
                    privacy_policy_url = '', 
                    terms_of_use_url = '', ),
                user = py_logto.models._api_interaction_consent_get_200_response_user._api_interaction_consent_get_200_response_user(
                    id = '0', 
                    name = '', 
                    avatar = '', 
                    username = '', 
                    primary_email = '', 
                    primary_phone = '', ),
                organizations = [
                    py_logto.models._api_interaction_consent_get_200_response_organizations_inner._api_interaction_consent_get_200_response_organizations_inner(
                        id = '0', 
                        name = '0', )
                    ],
                missing_oidc_scope = [
                    ''
                    ],
                missing_resource_scopes = [
                    py_logto.models._api_interaction_consent_get_200_response_missing_resource_scopes_inner._api_interaction_consent_get_200_response_missingResourceScopes_inner(
                        resource = py_logto.models._api_interaction_consent_get_200_response_missing_resource_scopes_inner_resource._api_interaction_consent_get_200_response_missingResourceScopes_inner_resource(
                            name = '0', 
                            id = '', ), 
                        scopes = [
                            py_logto.models._api_interaction_consent_get_200_response_missing_resource_scopes_inner_scopes_inner._api_interaction_consent_get_200_response_missingResourceScopes_inner_scopes_inner(
                                id = '0', 
                                name = '0', 
                                description = '', )
                            ], )
                    ],
                redirect_uri = ''
            )
        else:
            return ApiInteractionConsentGet200Response(
                application = py_logto.models._api_interaction_consent_get_200_response_application._api_interaction_consent_get_200_response_application(
                    id = '0', 
                    name = '0', 
                    branding = py_logto.models._api_interaction_consent_get_200_response_application_branding._api_interaction_consent_get_200_response_application_branding(
                        logo_url = '', 
                        dark_logo_url = '', 
                        favicon = '', ), 
                    display_name = '', 
                    privacy_policy_url = '', 
                    terms_of_use_url = '', ),
                user = py_logto.models._api_interaction_consent_get_200_response_user._api_interaction_consent_get_200_response_user(
                    id = '0', 
                    name = '', 
                    avatar = '', 
                    username = '', 
                    primary_email = '', 
                    primary_phone = '', ),
                redirect_uri = '',
        )
        """

    def testApiInteractionConsentGet200Response(self):
        """Test ApiInteractionConsentGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
