# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_hooks_id_patch200_response import ApiHooksIdPatch200Response

class TestApiHooksIdPatch200Response(unittest.TestCase):
    """ApiHooksIdPatch200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiHooksIdPatch200Response:
        """Test ApiHooksIdPatch200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiHooksIdPatch200Response`
        """
        model = ApiHooksIdPatch200Response()
        if include_optional:
            return ApiHooksIdPatch200Response(
                id = '0',
                name = '',
                event = 'PostRegister',
                events = [
                    'PostRegister'
                    ],
                config = py_logto.models._api_hooks_get_200_response_inner_config._api_hooks_get_200_response_inner_config(
                    url = '', 
                    headers = {
                        'key' : ''
                        }, 
                    retries = 1.337, ),
                signing_key = '',
                enabled = True,
                created_at = 1.337
            )
        else:
            return ApiHooksIdPatch200Response(
                id = '0',
                name = '',
                event = 'PostRegister',
                events = [
                    'PostRegister'
                    ],
                config = py_logto.models._api_hooks_get_200_response_inner_config._api_hooks_get_200_response_inner_config(
                    url = '', 
                    headers = {
                        'key' : ''
                        }, 
                    retries = 1.337, ),
                signing_key = '',
                enabled = True,
                created_at = 1.337,
        )
        """

    def testApiHooksIdPatch200Response(self):
        """Test ApiHooksIdPatch200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
