# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.organization_roles_api import OrganizationRolesApi


class TestOrganizationRolesApi(unittest.TestCase):
    """OrganizationRolesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationRolesApi()

    def tearDown(self) -> None:
        pass

    def test_api_organization_roles_get(self) -> None:
        """Test case for api_organization_roles_get

        Get organization roles
        """
        pass

    def test_api_organization_roles_id_delete(self) -> None:
        """Test case for api_organization_roles_id_delete

        Delete organization role
        """
        pass

    def test_api_organization_roles_id_get(self) -> None:
        """Test case for api_organization_roles_id_get

        Get organization role
        """
        pass

    def test_api_organization_roles_id_patch(self) -> None:
        """Test case for api_organization_roles_id_patch

        Update organization role
        """
        pass

    def test_api_organization_roles_id_scopes_get(self) -> None:
        """Test case for api_organization_roles_id_scopes_get

        Get organization role scopes
        """
        pass

    def test_api_organization_roles_id_scopes_organization_scope_id_delete(self) -> None:
        """Test case for api_organization_roles_id_scopes_organization_scope_id_delete

        Remove organization scope
        """
        pass

    def test_api_organization_roles_id_scopes_post(self) -> None:
        """Test case for api_organization_roles_id_scopes_post

        Assign organization scopes to organization role
        """
        pass

    def test_api_organization_roles_id_scopes_put(self) -> None:
        """Test case for api_organization_roles_id_scopes_put

        Replace organization scopes for organization role
        """
        pass

    def test_api_organization_roles_post(self) -> None:
        """Test case for api_organization_roles_post

        Create an organization role
        """
        pass


if __name__ == '__main__':
    unittest.main()
