# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_verification_codes_verify_post_request import ApiVerificationCodesVerifyPostRequest

class TestApiVerificationCodesVerifyPostRequest(unittest.TestCase):
    """ApiVerificationCodesVerifyPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiVerificationCodesVerifyPostRequest:
        """Test ApiVerificationCodesVerifyPostRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiVerificationCodesVerifyPostRequest`
        """
        model = ApiVerificationCodesVerifyPostRequest()
        if include_optional:
            return ApiVerificationCodesVerifyPostRequest(
                email = 'k@?x!u'K}qz^sEC)lJ*=-jQ+'6`%cClu,k'!'su[..zF6V,V6rEtCO?&28nxs#k8z)\"\\6\\%TMxo:-sWVoim9gs',
                verification_code = '0',
                phone = '4'
            )
        else:
            return ApiVerificationCodesVerifyPostRequest(
                email = 'k@?x!u'K}qz^sEC)lJ*=-jQ+'6`%cClu,k'!'su[..zF6V,V6rEtCO?&28nxs#k8z)\"\\6\\%TMxo:-sWVoim9gs',
                verification_code = '0',
                phone = '4',
        )
        """

    def testApiVerificationCodesVerifyPostRequest(self):
        """Test ApiVerificationCodesVerifyPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
