# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_interaction_mfa_put_request import ApiInteractionMfaPutRequest

class TestApiInteractionMfaPutRequest(unittest.TestCase):
    """ApiInteractionMfaPutRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiInteractionMfaPutRequest:
        """Test ApiInteractionMfaPutRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiInteractionMfaPutRequest`
        """
        model = ApiInteractionMfaPutRequest()
        if include_optional:
            return ApiInteractionMfaPutRequest(
                type = '',
                code = '',
                id = '',
                raw_id = '',
                authenticator_attachment = 'cross-platform',
                client_extension_results = py_logto.models._api_interaction_bind_mfa_post_request_one_of_1_client_extension_results._api_interaction_bind_mfa_post_request_oneOf_1_clientExtensionResults(
                    appid = True, 
                    crep_props = py_logto.models._api_interaction_bind_mfa_post_request_one_of_1_client_extension_results_crep_props._api_interaction_bind_mfa_post_request_oneOf_1_clientExtensionResults_crepProps(
                        rk = True, ), 
                    hmac_create_secret = True, ),
                response = py_logto.models._api_interaction_mfa_put_request_one_of_response._api_interaction_mfa_put_request_oneOf_response(
                    client_data_json = '', 
                    authenticator_data = '', 
                    signature = '', 
                    user_handle = '', )
            )
        else:
            return ApiInteractionMfaPutRequest(
                type = '',
                code = '',
                id = '',
                raw_id = '',
                client_extension_results = py_logto.models._api_interaction_bind_mfa_post_request_one_of_1_client_extension_results._api_interaction_bind_mfa_post_request_oneOf_1_clientExtensionResults(
                    appid = True, 
                    crep_props = py_logto.models._api_interaction_bind_mfa_post_request_one_of_1_client_extension_results_crep_props._api_interaction_bind_mfa_post_request_oneOf_1_clientExtensionResults_crepProps(
                        rk = True, ), 
                    hmac_create_secret = True, ),
                response = py_logto.models._api_interaction_mfa_put_request_one_of_response._api_interaction_mfa_put_request_oneOf_response(
                    client_data_json = '', 
                    authenticator_data = '', 
                    signature = '', 
                    user_handle = '', ),
        )
        """

    def testApiInteractionMfaPutRequest(self):
        """Test ApiInteractionMfaPutRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
