# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.verification_codes_api import VerificationCodesApi


class TestVerificationCodesApi(unittest.TestCase):
    """VerificationCodesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = VerificationCodesApi()

    def tearDown(self) -> None:
        pass

    def test_api_verification_codes_post(self) -> None:
        """Test case for api_verification_codes_post

        Request and send a verification code
        """
        pass

    def test_api_verification_codes_verify_post(self) -> None:
        """Test case for api_verification_codes_verify_post

        Verify a verification code
        """
        pass


if __name__ == '__main__':
    unittest.main()
