# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.hooks_api import HooksApi


class TestHooksApi(unittest.TestCase):
    """HooksApi unit test stubs"""

    def setUp(self) -> None:
        self.api = HooksApi()

    def tearDown(self) -> None:
        pass

    def test_api_hooks_get(self) -> None:
        """Test case for api_hooks_get

        Get hooks
        """
        pass

    def test_api_hooks_id_delete(self) -> None:
        """Test case for api_hooks_id_delete

        Delete hook
        """
        pass

    def test_api_hooks_id_get(self) -> None:
        """Test case for api_hooks_id_get

        Get hook
        """
        pass

    def test_api_hooks_id_patch(self) -> None:
        """Test case for api_hooks_id_patch

        Update hook
        """
        pass

    def test_api_hooks_id_recent_logs_get(self) -> None:
        """Test case for api_hooks_id_recent_logs_get

        Get recent logs for a hook
        """
        pass

    def test_api_hooks_id_signing_key_patch(self) -> None:
        """Test case for api_hooks_id_signing_key_patch

        Update signing key for a hook
        """
        pass

    def test_api_hooks_id_test_post(self) -> None:
        """Test case for api_hooks_id_test_post

        Test hook
        """
        pass

    def test_api_hooks_post(self) -> None:
        """Test case for api_hooks_post

        Create a hook
        """
        pass


if __name__ == '__main__':
    unittest.main()
